import React from 'react';

/**
 * @name react.mountable
 *
 * @desc
 * ```
 * (DOM -> Side Effects) -> Component
 * ```
 * Turn a non-react-aware function that expects a domnode
 * to mount into into a Component
 *
 * @example
 * const mountItalic = el => {
 *   el.innerHTML = '<em>Hello!</em>'
 * }
 *
 * const Italic = mountable(mountItalic)
 *
 * render(<Italic />, document.body)
 */

var mountable = function mountable(mountFn) {
  var div = void 0;
  return React.createClass({
    componentDidMount: function componentDidMount() {
      this.forceUpdate();
    },
    render: function render() {
      if (div) mountFn(div);
      return React.createElement('div', { ref: function ref(el) {
          div = el;
        } });
    }
  });
};

export default mountable;