'use strict';

exports.__esModule = true;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * @name react.mountable
 *
 * @desc
 * ```
 * (DOM -> Side Effects) -> Component
 * ```
 * Turn a non-react-aware function that expects a domnode
 * to mount into into a Component
 *
 * @example
 * const mountItalic = el => {
 *   el.innerHTML = '<em>Hello!</em>'
 * }
 *
 * const Italic = mountable(mountItalic)
 *
 * render(<Italic />, document.body)
 */

var mountable = function mountable(mountFn) {
  var div = void 0;
  return _react2.default.createClass({
    componentDidMount: function componentDidMount() {
      this.forceUpdate();
    },
    render: function render() {
      if (div) mountFn(div);
      return _react2.default.createElement('div', { ref: function ref(el) {
          div = el;
        } });
    }
  });
};

exports.default = mountable;
module.exports = exports['default'];